Range-v3: range/v3/algorithm/remove_copy_if.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
remove_copy_if.hpp File Reference

## Classes
struct | ranges::v3::remove_copy_if_fn

## Typedefs
template<typename I , typename O , typename C , typename P = ident>
using | ranges::v3::RemoveCopyableIf = meta::strict_and< InputIterator< I >, WeaklyIncrementable< O >, IndirectPredicate< C, projected< I, P > >, IndirectlyCopyable< I, O > >

## Variables
constexpr with_braced_init_args< remove_copy_if_fn > | ranges::v3::remove_copy_if {}